@@ -263,7 +263,7 @@ class RepositoryTester(unittest.TestCase):
         self.kwargs["linux_path"] = r"\mnt\M\Projects"
         new_repo = Repository(**self.kwargs)
 
-        self.assertNotIn("\\", new_repo.linux_path)
+        self.assertFalse("\\" in new_repo.linux_path)
         self.assertEqual(new_repo.linux_path, "/mnt/M/Projects/")
 
     def test_linux_path_attribute_backward_slashes_are_converted_to_forward_slashes(self):
@@ -271,7 +271,7 @@ class RepositoryTester(unittest.TestCase):
         in the linux_path attribute
         """
         self.test_repo.linux_path = r"\mnt\M\Projects"
-        self.assertNotIn("\\", self.test_repo.linux_path)
+        self.assertFalse("\\" in self.test_repo.linux_path)
         self.assertEqual(self.test_repo.linux_path, "/mnt/M/Projects/")
 
     def test_osx_path_argument_backward_slashes_are_converted_to_forward_slashes(self):
@@ -281,7 +281,7 @@ class RepositoryTester(unittest.TestCase):
         self.kwargs["osx_path"] = r"\Volumes\M\Projects"
         new_repo = Repository(**self.kwargs)
 
-        self.assertNotIn("\\", new_repo.linux_path)
+        self.assertFalse("\\" in new_repo.linux_path)
         self.assertEqual(new_repo.osx_path, "/Volumes/M/Projects/")
 
     def test_osx_path_attribute_backward_slashes_are_converted_to_forward_slashes(self):
@@ -289,7 +289,7 @@ class RepositoryTester(unittest.TestCase):
         in the osx_path attribute
         """
         self.test_repo.osx_path = r"\Volumes\M\Projects"
-        self.assertNotIn("\\", self.test_repo.osx_path)
+        self.assertFalse("\\" in self.test_repo.osx_path)
         self.assertEqual(self.test_repo.osx_path, "/Volumes/M/Projects/")
 
     def test_windows_path_argument_backward_slashes_are_converted_to_forward_slashes(self):
@@ -299,7 +299,7 @@ class RepositoryTester(unittest.TestCase):
         self.kwargs["windows_path"] = r"M:\Projects"
         new_repo = Repository(**self.kwargs)
 
-        self.assertNotIn("\\", new_repo.linux_path)
+        self.assertFalse("\\" in new_repo.linux_path)
         self.assertEqual(new_repo.windows_path, "M:/Projects/")
 
     def test_windows_path_attribute_backward_slashes_are_converted_to_forward_slashes(self):
@@ -307,7 +307,7 @@ class RepositoryTester(unittest.TestCase):
         in the windows_path attribute
         """
         self.test_repo.windows_path = r"M:\Projects"
-        self.assertNotIn("\\", self.test_repo.windows_path)
+        self.assertFalse("\\" in self.test_repo.windows_path)
         self.assertEqual(self.test_repo.windows_path, "M:/Projects/")
 
     def test_to_linux_path_returns_the_linux_version_of_the_given_windows_path(self):
